NAME
IWL::Menu - a menu widget
INHERITANCE
IWL::Object -> IWL::Widget -> IWL::Container -> IWL::List -> IWL::Menu
DESCRIPTION
A popup menu widget
CONSTRUCTOR
IWL::Menu->new ([%ARGS])
Where %ARGS is an optional hash parameter with with key-values.
SIGNALS
-
Fires when a menu item has been activated, via double clicking. Receives the activated item as a parameter
METHODS
- appendMenuItem (TEXT, [URL, %ARGS])
-
Appends text as a menu item to the current menu
Parameters: TEXT - the text, URL - the url of the item icon (if it's not of type 'radio' or 'check'). It can also be a stock icon id, %ARGS - the hash attributes of the menu item
- prependMenuItem (TEXT, [URL, %ARGS])
-
Prepends text as a menu item to the current menu
Parameters: TEXT - the text, URL - the url of the item icon. It can also be a stock icon id, %ARGS - the hash attributes of the menu item
- appendMenuSeparator
-
Appends a separator to the menu
- prependMenuSeparator
-
Prepends a separator to the menu
- bindToWidget (WIDGET, SIGNAL)
-
Binds the menu to pop up when the specified widget emits the given signal
Parameters: WIDGET - the widget to bind to, SIGNAL - the signal the widget will emit to pop up the menu
Note: The widget ID must not be changed after this method is called.
- setMaxHeight (HEIGHT)
-
Sets the max height of the menu, after which it will become a scrollable menu
Parameters: HEIGHT - the desired max height of the menu (in pixels). Setting this parameter to 0 will turn the option off
- getMaxHeight
-
Returns the max height of the menu
LICENCE AND COPYRIGHT
Copyright (c) 2006-2007 Viktor Kojouharov. All rights reserved.
This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself. See perldoc perlartistic.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
1 POD Error
The following errors were encountered while parsing the POD:
- Around line 220:
You forgot a '=back' before '=head1'